@@ -27,12 +27,14 @@ def test_set_and_get_auth_token():
 
 def test_set_and_get_registry_token():
     """testing setting token"""
+    test_access_id = "SOMEID"
     test_secret = "YULE NEFFER GESS WOT"
     test_secret_file = ".test_eosecrets.toml"
 
-    embedops_authorization.set_registry_token(test_secret, test_secret_file)
-    retrieved_secret = embedops_authorization.get_registry_token(test_secret_file)
+    embedops_authorization.set_registry_token(test_access_id, test_secret, test_secret_file)
+    retrieved_id, retrieved_secret = embedops_authorization.get_registry_token(test_secret_file)
 
+    assert test_access_id == retrieved_id
     assert test_secret == retrieved_secret
 
     os.remove(test_secret_file)
@@ -43,25 +45,28 @@ def test_setting_both_tokens():
 
     auth_secret = "SUPER_DUPER_SECRET_TOKN_SAUCE"
     other_auth_secret = "THIS IS THE GOOD ONE"
+    registry_id = "SOMEID"
     registry_secret = "YULE NEFFER GESS WOT"
 
     test_secret_file = ".test_eosecrets.toml"
 
     embedops_authorization.set_auth_token(auth_secret, test_secret_file)
-    embedops_authorization.set_registry_token(registry_secret, test_secret_file)
+    embedops_authorization.set_registry_token(registry_id, registry_secret, test_secret_file)
 
     read_auth_token = embedops_authorization.get_auth_token(test_secret_file)
-    read_registry_token = embedops_authorization.get_registry_token(test_secret_file)
+    read_registry_id, read_registry_secret = embedops_authorization.get_registry_token(test_secret_file)
 
     assert auth_secret == read_auth_token
-    assert registry_secret == read_registry_token
+    assert registry_id == read_registry_id
+    assert registry_secret == read_registry_secret
 
     embedops_authorization.set_auth_token(other_auth_secret, test_secret_file)
     read_auth_token = embedops_authorization.get_auth_token(test_secret_file)
-    read_registry_token = embedops_authorization.get_registry_token(test_secret_file)
+    read_registry_id, read_registry_secret = embedops_authorization.get_registry_token(test_secret_file)
 
     assert other_auth_secret == read_auth_token
-    assert registry_secret == read_registry_token
+    assert registry_id == read_registry_id
+    assert registry_secret == read_registry_secret
 
     os.remove(test_secret_file)
 
@@ -86,7 +91,7 @@ def test_login_to_registry_incorrect_registry_credentials_fails_login(mocker):
 
     mocker.patch(
         "embedops_cli.embedops_authorization.get_registry_token",
-        return_value="BAD_TOKEN_BAD"
+        return_value=("BAD_TOKEN_ID_BAD", "BAD_TOKEN_SECRET_BAD")
     )
     mocker.patch(
         "embedops_cli.embedops_authorization.docker_cli_login",
@@ -103,7 +108,7 @@ def test_login_to_registry(mocker):
     """Test that the function handles a successful login correctly"""
     mock_get_registry_token = mocker.patch(
         "embedops_cli.embedops_authorization.get_registry_token",
-        return_value="MAGIC_GOOD_TOKEN"
+        return_value=("MAGIC_GOOD_TOKEN_ID","MAGIC_GOOD_TOKEN_SECRET")
     )
     mock_docker_cli_login = mocker.patch(
         "embedops_cli.embedops_authorization.docker_cli_login",
